Electromagnetic Radiation (EMR) Calculator
==========================================

#### Overview

This project implements a Python 3.7+ Tkinter GUI to facilitate the following EMR calculations which I find useful as a student of Astrophysics:
- Conversion between Energy, Frequency, and Wavelength.
- Editing the units or quantities of any of those 3 characteristics.
- Display of the kJ/mol equivalent.
- Display of the related EMR band as defined by NASA.
- Automatic update of quantities and EMR band name after editing.

Some special files in addition to the emrcalc/*.py source code:
- ```HISTORY.txt``` - the update history
- ```misc/SCREENSHOT.png``` - a sample screenshot
- ```misc/url.txt``` - URLs to background information

#### Dependencies

```
numpy
scipy
tkinter - included with Python 3
tkinter.ttk - included with Python 3
```

#### Installation

```
python3 -m pip install emrcalc
```

#### Invocation from a terminal window command-line

```
emrcalc
```

#### Licensing

This is NOT commercial software; instead, usage is covered by the GNU General Public License version 3 (2007). In a nutshell, please feel free to use the project and share it as you will but please don't sell it. Thank you!

See the LICENSE file for the GNU licensing information.

Feel free to create an issue record for any questions, bugs, or enhancement requests. I'll respond as soon as I can.

Richard Elkins

Dallas, Texas, USA, 3rd Rock, Sol, ...
